==> QuickAMS-1.1.14-sources.jar: cn/schoolwow/ams/service/DefaultAMSDispatcherService.java <==
package cn.schoolwow.ams.service;

import cn.schoolwow.ams.flow.dispatcher.*;
import cn.schoolwow.ams.listener.AMSRemoteSelect;
import cn.schoolwow.quickflow.QuickFlow;
import cn.schoolwow.quickflow.domain.FlowContext;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

import java.util.Collection;
import java.util.Map;

public class DefaultAMSDispatcherService implements AMSDispatcherService{
    private QuickFlow amsFlow;
    
    public DefaultAMSDispatcherService(QuickFlow amsFlow) {
        this.amsFlow = amsFlow;
    }

    @Override
    public JSONObject list(String projectName, String daoName, String tableName, Map<String, Object> amsListConditionMap) {
        FlowContext flowContext = amsFlow.startFlow(new ListFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("amsListConditionMap", amsListConditionMap)
                .execute();
        JSONObject amsPagingList = (JSONObject) flowContext.checkData("amsPagingList");
        return amsPagingList;
    }

    @Override
    public void create(String projectName, String daoName, String tableName, JSONObject createEntity) {
        amsFlow.startFlow(new CreateFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("createEntity", createEntity)
                .execute();
    }

    @Override
    public void edit(String projectName, String daoName, String tableName, JSONObject updateEntity) {
        amsFlow.startFlow(new EditFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("updateEntity", updateEntity)
                .execute();
    }

    @Override
    public void delete(String projectName, String daoName, String tableName, Map<String, Object> amsListConditionMap) {
        amsFlow.startFlow(new DeleteFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("amsListConditionMap", amsListConditionMap)
                .execute();
    }

    @Override
    public JSONObject operationDispatcher(String projectName, String daoName, String tableName, String methodName, JSONObject requestBody) throws Exception {
        FlowContext flowContext = amsFlow.startFlow(new OperationDispatcherFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("methodName", methodName)
                .putCurrentCompositeFlowData("requestBody", requestBody)
                .execute();
        JSONObject response = (JSONObject) flowContext.getData("response");
        return response;
    }

    @Override
    public JSONArray remoteSelect(String projectName, String type, Map<String, String> amsListConditionMap) throws Exception {
        Collection<AMSRemoteSelect> amsRemoteSelectList = (Collection<AMSRemoteSelect>) amsFlow.getContextData("amsRemoteSelectList");
        for(AMSRemoteSelect amsRemoteSelect:amsRemoteSelectList){
            if(type.equalsIgnoreCase(amsRemoteSelect.type())){
                return amsRemoteSelect.getRemoteOption(amsListConditionMap);
            }
        }
        throw new IllegalArgumentException("未匹配到下拉框选项!项目名:"+projectName+",类型:"+type);
    }

}

==> QuickAMS-1.1.17-sources.jar: cn/schoolwow/ams/service/DefaultAMSDispatcherService.java <==
package cn.schoolwow.ams.service;

import cn.schoolwow.ams.flow.dispatcher.*;
import cn.schoolwow.ams.flow.dispatcher.common.DispatcherBeforeAfterFlow;
import cn.schoolwow.ams.listener.AMSRemoteSelect;
import cn.schoolwow.quickflow.QuickFlow;
import cn.schoolwow.quickflow.domain.FlowContext;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

import java.util.Collection;
import java.util.Map;

public class DefaultAMSDispatcherService implements AMSDispatcherService{
    private QuickFlow amsFlow;
    
    public DefaultAMSDispatcherService(QuickFlow amsFlow) {
        this.amsFlow = amsFlow;
    }

    @Override
    public JSONObject list(String projectName, String daoName, String tableName, Map<String, Object> amsListConditionMap) {
        FlowContext flowContext = amsFlow.startFlow(new ListFlow())
                .beforeAfterFlowHandler(new DispatcherBeforeAfterFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("amsListConditionMap", amsListConditionMap)
                .execute();
        JSONObject amsPagingList = (JSONObject) flowContext.checkData("amsPagingList");
        return amsPagingList;
    }

    @Override
    public void create(String projectName, String daoName, String tableName, JSONObject createEntity) {
        amsFlow.startFlow(new CreateFlow())
                .beforeAfterFlowHandler(new DispatcherBeforeAfterFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("createEntity", createEntity)
                .execute();
    }

    @Override
    public void edit(String projectName, String daoName, String tableName, JSONObject updateEntity) {
        amsFlow.startFlow(new EditFlow())
                .beforeAfterFlowHandler(new DispatcherBeforeAfterFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("updateEntity", updateEntity)
                .execute();
    }

    @Override
    public void delete(String projectName, String daoName, String tableName, Map<String, Object> amsListConditionMap) {
        amsFlow.startFlow(new DeleteFlow())
                .beforeAfterFlowHandler(new DispatcherBeforeAfterFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("amsListConditionMap", amsListConditionMap)
                .execute();
    }

    @Override
    public JSONObject operationDispatcher(String projectName, String daoName, String tableName, String methodName, JSONObject requestBody) throws Exception {
        FlowContext flowContext = amsFlow.startFlow(new OperationDispatcherFlow())
                .beforeAfterFlowHandler(new DispatcherBeforeAfterFlow())
                .putCurrentCompositeFlowData("projectName", projectName)
                .putCurrentCompositeFlowData("daoName", daoName)
                .putCurrentCompositeFlowData("tableName", tableName)
                .putCurrentCompositeFlowData("methodName", methodName)
                .putCurrentCompositeFlowData("requestBody", requestBody)
                .execute();
        JSONObject response = (JSONObject) flowContext.getData("response");
        return response;
    }

    @Override
    public JSONArray remoteSelect(String projectName, String type, Map<String, String> amsListConditionMap) throws Exception {
        Collection<AMSRemoteSelect> amsRemoteSelectList = (Collection<AMSRemoteSelect>) amsFlow.getContextData("amsRemoteSelectList");
        for(AMSRemoteSelect amsRemoteSelect:amsRemoteSelectList){
            if(type.equalsIgnoreCase(amsRemoteSelect.type())){
                return amsRemoteSelect.getRemoteOption(amsListConditionMap);
            }
        }
        throw new IllegalArgumentException("未匹配到下拉框选项!项目名:"+projectName+",类型:"+type);
    }

}
